pub struct Journal { /* private fields */ }Implementations
Sourceimpl Journal
impl Journal
Sourcepub fn open(path: &Path) -> Result<Self, String>
pub fn open(path: &Path) -> Result<Self, String>
Exclusive process lock prevents two showcase processes sharing the same store. Existing data is never repaired, reset or deleted automatically.
pub fn load(&self) -> Option<Value>
pub fn latest(&self) -> Option<Receipt>
pub fn commit( &self, state: Value, action: &Action, source: Source, ) -> Result<Receipt, String>
pub fn history(&self, limit: usize) -> Vec<Value>
pub fn state_as_of(&self, seq: u64) -> Option<Value>
pub fn verify(&self) -> Result<usize, String>